import { PageHeading } from "@src/components/common/headings/pageHeading";
import { TodoList } from "@src/components/todos";
import { ProjectsHeading } from "@src/components/common/headings/projectsHeading";
import { groupByProjects } from "@src/core/actions/utility/groupByProjects";
import { todosApi } from "@src/infrastructure/apis/todosApi";
import { AddTodo } from "@src/components/todos/addTodo";

const HomePage = () => {
  const { data, isLoading } = todosApi.useGetAllTodosQuery();

  if (isLoading) {
    return "loading...";
  }

  const groupedTodos = groupByProjects(data);
  const sections = Object.keys(groupedTodos)
    .filter((s) => s !== "inbox")
    .sort();
  return (
    <main className="py-8 px-14 space-y-6">
      <section className="space-y-8 mx-auto max-w-4xl">
        {groupedTodos["inbox"] && (
          <div className="space-y-2">
            <PageHeading title="Inbox" />
            <TodoList
              todos={groupedTodos["inbox"]}
              hideDone
              project={""}
              hideProject={false}
            />
          </div>
        )}
        {sections &&
          sections.map((section) => (
            <div key={section} className="space-y-2">
              <ProjectsHeading title={section} />
              <TodoList
                todos={groupedTodos[section]}
                hideDone
                project={section}
                hideProject
              />
            </div>
          ))}
        {data && data.length === 0 && (
          <div className="space-y-4">
            <PageHeading title="You're done!" />
            <AddTodo project={""} />
          </div>
        )}
      </section>
    </main>
  );
};
export default HomePage;
